==> config-api-0.4.2-sources.jar: org/wildfly/swarm/config/undertow/servlet_container/WebsocketsSetting.java <==
package org.wildfly.swarm.config.undertow.servlet_container;

import org.wildfly.swarm.config.runtime.Address;
import java.util.HashMap;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * If websockets are enabled for this container
 */
@Address("/subsystem=undertow/servlet-container=*/setting=websockets")
@ResourceType("setting")
@Implicit
public class WebsocketsSetting<T extends WebsocketsSetting<T>> extends HashMap {

	private String key;
	private PropertyChangeSupport pcs;
	private String bufferPool;
	private Boolean dispatchToWorker;
	private String worker;

	public WebsocketsSetting() {
		super();
		this.key = "websockets";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * The buffer pool to use for websocket deployments
	 */
	@ModelNodeBinding(detypedName = "buffer-pool")
	public String bufferPool() {
		return this.bufferPool;
	}

	/**
	 * The buffer pool to use for websocket deployments
	 */
	@SuppressWarnings("unchecked")
	public T bufferPool(String value) {
		Object oldValue = this.bufferPool;
		this.bufferPool = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("bufferPool", oldValue, value);
		return (T) this;
	}

	/**
	 * If callbacks should be dispatched to a worker thread. If this is false
	 * then they will be run in the IO thread, which is faster however care must
	 * be taken not to perform blocking operations.
	 */
	@ModelNodeBinding(detypedName = "dispatch-to-worker")
	public Boolean dispatchToWorker() {
		return this.dispatchToWorker;
	}

	/**
	 * If callbacks should be dispatched to a worker thread. If this is false
	 * then they will be run in the IO thread, which is faster however care must
	 * be taken not to perform blocking operations.
	 */
	@SuppressWarnings("unchecked")
	public T dispatchToWorker(Boolean value) {
		Object oldValue = this.dispatchToWorker;
		this.dispatchToWorker = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("dispatchToWorker", oldValue, value);
		return (T) this;
	}

	/**
	 * The worker to use for websocket deployments
	 */
	@ModelNodeBinding(detypedName = "worker")
	public String worker() {
		return this.worker;
	}

	/**
	 * The worker to use for websocket deployments
	 */
	@SuppressWarnings("unchecked")
	public T worker(String value) {
		Object oldValue = this.worker;
		this.worker = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("worker", oldValue, value);
		return (T) this;
	}
}

==> config-api-0.4.8-sources.jar: org/wildfly/swarm/config/undertow/servlet_container/WebsocketsSetting.java <==
package org.wildfly.swarm.config.undertow.servlet_container;

import org.wildfly.swarm.config.runtime.Address;
import java.util.HashMap;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;

/**
 * If websockets are enabled for this container
 */
@Address("/subsystem=undertow/servlet-container=*/setting=websockets")
@ResourceType("setting")
@Implicit
public class WebsocketsSetting<T extends WebsocketsSetting<T>> extends HashMap {

	private String key;
	private PropertyChangeSupport pcs;
	private String bufferPool;
	private Boolean dispatchToWorker;
	private String worker;

	public WebsocketsSetting() {
		super();
		this.key = "websockets";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(
			java.beans.PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * The buffer pool to use for websocket deployments
	 */
	@ModelNodeBinding(detypedName = "buffer-pool")
	public String bufferPool() {
		return this.bufferPool;
	}

	/**
	 * The buffer pool to use for websocket deployments
	 */
	@SuppressWarnings("unchecked")
	public T bufferPool(java.lang.String value) {
		Object oldValue = this.bufferPool;
		this.bufferPool = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("bufferPool", oldValue, value);
		return (T) this;
	}

	/**
	 * If callbacks should be dispatched to a worker thread. If this is false
	 * then they will be run in the IO thread, which is faster however care must
	 * be taken not to perform blocking operations.
	 */
	@ModelNodeBinding(detypedName = "dispatch-to-worker")
	public Boolean dispatchToWorker() {
		return this.dispatchToWorker;
	}

	/**
	 * If callbacks should be dispatched to a worker thread. If this is false
	 * then they will be run in the IO thread, which is faster however care must
	 * be taken not to perform blocking operations.
	 */
	@SuppressWarnings("unchecked")
	public T dispatchToWorker(java.lang.Boolean value) {
		Object oldValue = this.dispatchToWorker;
		this.dispatchToWorker = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("dispatchToWorker", oldValue, value);
		return (T) this;
	}

	/**
	 * The worker to use for websocket deployments
	 */
	@ModelNodeBinding(detypedName = "worker")
	public String worker() {
		return this.worker;
	}

	/**
	 * The worker to use for websocket deployments
	 */
	@SuppressWarnings("unchecked")
	public T worker(java.lang.String value) {
		Object oldValue = this.worker;
		this.worker = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("worker", oldValue, value);
		return (T) this;
	}
}
